##  Reference Catalog
To enhance data quality, you can use the reference catalog that offers reference data and best-practice recommendations for business capabilities, applications, IT components, and tech categories. By implementing reference data and synchronizing information from the catalog, you can streamline the setup and maintenance of your inventory. Automatic synchronization not only ensures that your data remains current and consistent, but also optimizes your workflows by reducing manual updates.
For a detailed guide, see [Reference Catalog](https://help.sap.com/docs/leanix/ea/reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "The reference catalog provides reference data for business capabilities, applications, IT components, and tech categories, which enables you to set up and maintain your inventory more efficiently.").
